@@ -1,7 +1,7 @@
 package Software::Catalog::SW::zcoin::qt;
 
-our $DATE = '2018-10-05'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2018-10-18'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -27,7 +27,7 @@ sub get_latest_version {
 
     extract_from_url(
         url => "https://github.com/zcoinofficial/zcoin/releases",
-        re  => qr!/zcoinofficial/zcoin/releases/download/\d+(?:\.\d+)+/zcoin(?:-qt)?-(\d+(?:\.\d+)+)-linux64\.!,
+        re  => qr!/zcoinofficial/zcoin/releases/download/v?\d+(?:\.\d+)+/zcoin(?:-qt)?-(\d+(?:\.\d+)+)-linux64\.!,
     );
 }
 
@@ -94,7 +94,7 @@ Software::Catalog::SW::zcoin::qt - Zcoin desktop GUI client
 
 =head1 VERSION
 
-This document describes version 0.003 of Software::Catalog::SW::zcoin::qt (from Perl distribution Software-Catalog-SW-zcoin-qt), released on 2018-10-05.
+This document describes version 0.004 of Software::Catalog::SW::zcoin::qt (from Perl distribution Software-Catalog-SW-zcoin-qt), released on 2018-10-18.
 
 =for Pod::Coverage ^(.+)$
 
